@@ -11,8 +11,7 @@
         kdepim/incidenceeditors/editorattachments.{h,cpp}
 */
 
-#ifndef INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
-#define INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
+#pragma once
 
 #include <KCalendarCore/Attachment>
 
@@ -21,11 +20,13 @@
 
 #include <QListWidget>
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 class AttachmentIconView : public QListWidget
 {
     Q_OBJECT
     friend class EditorAttachments;
+
 public:
     explicit AttachmentIconView(QWidget *parent = nullptr);
 
@@ -41,7 +42,7 @@ class AttachmentIconItem : public QListWidgetItem
 {
 public:
     AttachmentIconItem(const KCalendarCore::Attachment &att, QListWidget *parent);
-    ~AttachmentIconItem();
+    ~AttachmentIconItem() override;
 
     Q_REQUIRED_RESULT KCalendarCore::Attachment attachment() const;
     Q_REQUIRED_RESULT const QString uri() const;
@@ -74,4 +75,3 @@ private:
 };
 }
 
-#endif // INCIDENCEEDITOR_ATTACHMENTICONVIEW_H
